# UpdateTectonFeatureDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | [optional] 
**column_name** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**feature_view_id** | **str** |  | [optional] 
**feature_table_id** | **str** |  | [optional] 
**metadata** | **object** |  | [optional] 
**synced_at** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

